﻿/* jQuery extension to get Query String parameters */
$.extend({
    getUrlVars: function () {
        var vars = [], hash;
        var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1).split('&');
        for (var i = 0; i < hashes.length; i++) {
            hash = hashes[i].split('=');
            vars.push(hash[0]);
            vars[hash[0]] = hash[1];
        }
        return vars;
    },
    getUrlVar: function (name) {
        return $.getUrlVars()[name];
    }
});

/* Library to draw indicators */

function c_convertAngle(angle) {
    return (angle * Math.PI / 2) / 90;
}

/* Constants */

var COLOR_VERY_LIGHT_GRAY = "#c0c0c0";
var COLOR_LIGHT_GRAY = "#f1f1f1";
var COLOR_GRAY = "#666666";
var COLOR_ORANGE = "#f15a22";
var COLOR_RED = "#ff0000";
var COLOR_BLUE = "#0000ff";
var COLOR_BLACK = "#000000";
var WIDTH_STROKE_2 = 2;
var WIDTH_STROKE_1 = 1;
var WIDTH_STROKE_0 = 0;
var RADIUS_BOX = 5;
var OPACITY_0_5 = 0.5;

function buildTopCircleGauge(canvasId, min, max, nominalMax, value, interval, absMin, absMax, percSize) {

    //Input: dimensions
    var width, height, radius, cx, cy, cap_radius;
    //Input: style
    //var fill, stroke, stroke_width, tick_width;
    //var capFill;
    //var pointerFill;

    var angle, angle2, tick, font_size;
    var paper, gauge, path, pointer_radius;
    var deltaX, deltaX2, deltaY, deltaY2;

    try {

        //If max is too low, input interval could be 0: endless loop
        if (interval == 0) interval = 1;

        value = parseFloat(value);

        //All the calculations are done based on "0" (as min)
        var tmpMin, tmpMax, tmpValue, tmpAbsMin, tmpAbsMax, tmpNominalMax, tmpValue;
        tmpMin = 0; //min - min
        tmpMax = max - min;
        tmpAbsMin = absMin - min;
        tmpAbsMax = absMax - min;
        tmpNominalMax = nominalMax - min;
        tmpValue = value - min;

        width = Math.floor(200 * percSize);
        height = Math.floor(200 * percSize);
        radius = Math.floor(100 * percSize);
        cap_radius = Math.floor(10 * percSize);
        pointer_radius = Math.floor(75 * percSize);
        //stroke_width = 2;
        //tick_width = 2;
        //fill = "#f1f1f1";
        //stroke = "#666666";
        //capFill = "#666666";
        //pointerFill = "#f15a22";
        font_size = Math.floor(12 * percSize);

        cx = width / 2;
        cy = height / 2;

        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;

        paper = new Raphael(canvas, width, height);

        //Quadrante
        gauge = paper.circle(cx, cy, radius);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
        //Range interno
        if (tmpNominalMax <= tmpMax) {
            //Range: 0 --> nominal max
            deltaX = Math.floor(0.85 * pointer_radius * Math.sin(c_convertAngle(30)));
            deltaY = Math.floor(0.85 * pointer_radius * Math.cos(c_convertAngle(30)));
            angle = -1 * (c_convertAngle(120) + (tmpNominalMax * c_convertAngle(300)) / tmpMax);
            if (tmpNominalMax < tmpMax / 2) {
                gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle)), "A", 0.75 * pointer_radius, 0.75 * pointer_radius, 1, 0, 0, cx - deltaX, cy + deltaY]);
            } else {
                gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 1, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle)), "A", 0.75 * pointer_radius, 0.75 * pointer_radius, 1, 1, 0, cx - deltaX, cy + deltaY]);
            }
            gauge.attr("fill", COLOR_VERY_LIGHT_GRAY);
            gauge.attr("stroke", COLOR_VERY_LIGHT_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
            //Range: nominal max -->  max
            angle2 = -1 * (c_convertAngle(120) + (tmpMax * c_convertAngle(300)) / tmpMax);
            if (tmpNominalMax < tmpMax / 2) {
                gauge = paper.path(["M", Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 1, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle2)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle2)), "A", 0.70 * pointer_radius, 0.65 * pointer_radius, 0, 1, 0, Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle))]);
            } else {
                gauge = paper.path(["M", Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle2)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle2)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 1, 0, 0, Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle))]);
            }
            gauge.attr("fill", COLOR_GRAY);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
        }
        //Tick: arc
        deltaX = Math.floor(pointer_radius * Math.sin(c_convertAngle(30)));
        deltaY = Math.floor(pointer_radius * Math.cos(c_convertAngle(30)));
        gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", pointer_radius, pointer_radius, 0, 1, 1, cx + deltaX, cy + deltaY]);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_2);
        //Tick: values (major)
        tick = tmpMin;
        while (tick <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle))]);
            //gauge.attr("fill",fill);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_2);
            tick += interval;
        }
        //Tick: values (minor)
        tick = interval / 2;
        while (tick <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.95 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.95 * pointer_radius * Math.sin(angle))]);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_2);
            tick += interval;
        }
        //Tick: values (all the calcutions are "0" based but actual values must be written
        tick = tmpMin;
        while (tick <= tmpMax) {
            try {
                angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
                //gauge = paper.text(Math.floor(cx + 1.13 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.13 * pointer_radius * Math.sin(angle)), Math.round((tick + min) * 100) / 100);
                gauge = paper.text(Math.floor(cx + 1.18 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.18 * pointer_radius * Math.sin(angle)), Math.round(tick + min));
                gauge.attr("fill", COLOR_GRAY);
                gauge.attr("font", font_size + "px Arial");
            } catch (ex) { }
            tick += interval;
        }
        //Pointer (abs min)
        /*if (tmpAbsMin > tmpMin) {
            angle = -1 * (c_convertAngle(120) + (tmpAbsMin * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "Z"]);
            gauge.attr("fill", COLOR_RED);
            gauge.attr("stroke", COLOR_RED);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
            gauge.attr("opacity", OPACITY_0_5);
        }*/
        //Pointer (abs max)
        /*if (tmpAbsMax > tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tmpAbsMax * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))], "Z");
            gauge.attr("fill", COLOR_BLUE);
            gauge.attr("stroke", COLOR_BLUE);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
            gauge.attr("opacity", OPACITY_0_5);
        }*/
        //Pointer
        if (tmpValue <= tmpMin) {
            //Value smaller than Max
            angle = -1.9;
        } else if (tmpValue >= tmpMax) {
            //Value bigger than Max
            angle = -1.2;
        } else if (tmpValue>= tmpMin && tmpValue <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tmpValue * c_convertAngle(300)) / tmpMax);
        }
        gauge = paper.path(["M", cx + Math.floor(5 * Math.cos(angle + Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle + Math.PI / 2)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "L", cx + Math.floor(5 * Math.cos(angle - Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle - Math.PI / 2)), "Z"]);
        gauge.attr("fill", COLOR_ORANGE);
        gauge.attr("stroke", COLOR_ORANGE);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
        //Cap
        gauge = paper.circle(cx, cy, cap_radius);
        gauge.attr("fill", "r(0.25, 0.75)#ffffff-#000000");
        gauge.attr("stroke", COLOR_BLACK);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
    } catch (ex) {
        //alert(ex.message);
    }
}

/* OBSOLETE */

function buildTopBar(canvasId, min, max, value, interval, redMin, redMax, percSize) {

    //Values
    //var min, max, value, interval, font_size, redMin, redMax;
    //Input: style
    var fill, stroke, stroke_width, tick_width;
    var capFill;
    var pointerFill;
    var cy;

    var paper, gauge, path;
    var font_size = 12;

    try {

        //If max is too low, input interval could be 0: endless loop
        if (interval == 0) interval = 1;

        value = parseFloat(value);

        width = Math.floor(75 * percSize);
        height = Math.floor(220 * percSize);
        stroke_width = 2;
        tick_width = 2;
        fill = "#f1f1f1";
        stroke = "#666666";
        capFill = "#666666";
        pointerFill = "#f15a22";
        font_size = Math.floor(font_size * percSize);

        var canvas = document.getElementById(canvasId);
        if (canvas == null) {
            //alert("Canvas not found: " + canvasId);
            return;
        }

        paper = new Raphael(canvas, width, height);

        //Rettangolo esterno
        gauge = paper.rect(0, 0, width, height, 5);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Tick
        //gauge = paper.path(["M", 25, 15, "V", height - 15]);
        gauge = paper.path(["M", Math.floor(25 * percSize), 15, "V", height - 15]);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Tick: major
        tick = min;
        while (tick <= max) {
            cy = (height - 15) - tick * (height - 30) / max;
            //gauge = paper.path(["M", 25, cy, "L", 30, cy]);
            gauge = paper.path(["M", Math.floor(25 * percSize), cy, "L", Math.floor(30 * percSize), cy]);
            if (tick >= redMin && tick <= redMax && redMin != 0 && redMax != 0) {
                gauge.attr("stroke", "#ff0000");
            } else {
                gauge.attr("stroke", stroke);
            }
            gauge.attr("stroke-width", tick_width);
            tick += interval;
        }
        //Tick: values
        tick = min;
        while (tick <= max) {
            try {
                cy = (height - 15) - tick * (height - 30) / max;
                //gauge = paper.text(12, cy, tick);
                //gauge = paper.text(Math.floor(10 * percSize), cy, tick);
                gauge = paper.text(Math.floor(10 * percSize), cy, Math.round(tick));
                if (tick >= redMin && tick <= redMax && redMin != 0 && redMax != 0) {
                    gauge.attr("fill", "#ff0000");
                } else {
                    gauge.attr("fill", stroke);
                }
                gauge.attr("font", font_size + "px Arial");
            } catch (ex) { }
            tick += interval;
        }
        //Tick (red)
        if (redMin != null && redMin != 0 && redMax != null && redMax != 0) {
            cy = (redMax - redMin) * (height - 30) / max;
            //gauge = paper.path(["M", 25, 15, "V", cy + 15]);
            gauge = paper.path(["M", Math.floor(25 * percSize), 15, "V", cy + 15]);
            gauge.attr("fill", "#ff0000");
            gauge.attr("stroke", "#ff0000");
            gauge.attr("stroke-width", 1);
        }
        //Value (bar)	
        cy = (height - 15) - value * (height - 30) / max;
        //gauge = paper.rect(35, cy, 39, height - 15 - cy, 0);
        gauge = paper.rect(Math.floor(35 * percSize), cy, 39, height - 15 - cy, 0);
        gauge.attr("fill", "#f15a22");
        gauge.attr("stroke", "#f15a22");
        gauge.attr("stroke-width", 0);
    } catch (ex) {
        //alert(ex.Message);
    }
}

function buildTopBar2_0(canvasId, min, max, value, nominalValue,  percSize) {

    //Values

    var canvas, paper, gauge, path;
    //Box: width and height
    var box_x0, box_x1, box_y0, box_y1;
    var scale_x, scale_y0, scale_y100;
    //Text
    var text_x;
    var font_Size;
    //Interval
    var range, intervalValue, intervalY;
    //Values
    var min_y, max_y, nv_y, value_y;
    //UI
    var stroke_width,tick_width;

    try {

        //Init
        box_x0 = 0;
        box_y0 = 0;
        box_x1 = Math.floor(75 * percSize);
        box_y1 = Math.floor(220 * percSize);
        text_x = box_x0 + 10;
        font_size = Math.floor(12 * percSize);
        range = max - min;
        scale_x = Math.floor(27 * percSize);
        scale_y0 = box_y1 - 15;
        scale_y100 = 15;
        min_y = scale_y0;
        max_y = scale_y100;
        nv_y = (scale_y0 - (nominalValue - min) * (scale_y0 - scale_y100) / range) * percSize;
        value_y = (scale_y0 - (value - min) * (scale_y0 - scale_y100) / range) * percSize;
        intervalValue = nominalValue - min;
        intervalY = scale_y0 - nv_y;
        
        stroke_width = 2;
        tick_width = 2;

        //Init Raphael.js
        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;
        paper = new Raphael(canvas, box_x1, box_y1);

        //Box esterno
        gauge = paper.rect(box_x0, box_y0, box_x1, box_y1, RADIUS_BOX);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Scale
        gauge = paper.path(["M", scale_x, scale_y0, "V", scale_y100]);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Scale red
        gauge = paper.path(["M", scale_x, scale_y100, "V", nv_y]);
        gauge.attr("fill", COLOR_RED);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Value (bar)
        if (value >= min && value <= max) {
            gauge = paper.rect(scale_x + 5, value_y, box_x1 - scale_x - 10, scale_y0 - value_y);
            gauge.attr("fill", COLOR_ORANGE);
            gauge.attr("stroke", COLOR_ORANGE);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
        }

        //Values: min, max, nominal value
        gauge = paper.text(box_x0 + 12, min_y, Math.round(min));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_GRAY);
        gauge = paper.path(["M", scale_x - WIDTH_STROKE_1, min_y, "H", scale_x + 5]);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        gauge = paper.text(box_x0 + 12, nv_y, Math.round(nominalValue));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_RED);
        gauge = paper.path(["M", scale_x - WIDTH_STROKE_1, nv_y, "H", scale_x + 5]);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        gauge = paper.text(box_x0 + 12, max_y, Math.round(max));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_RED);
        gauge = paper.path(["M", scale_x - WIDTH_STROKE_1, max_y, "H", scale_x + 5]);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Ticks
        for (i = 0; i < 4; i++) {
            gauge = paper.text(box_x0 + 12, min_y - (intervalY / 4) * i, Math.round(min + (intervalValue / 4) * i));
            gauge.attr("font", font_size + "px Arial");
            gauge.attr("fill", COLOR_GRAY);
            gauge = paper.path(["M", scale_x - WIDTH_STROKE_1, min_y - (intervalY / 4) * i, "H", scale_x + 5]);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
        }

    } catch (ex) {
        alert(ex.Message);
    }
}

/* OBSOLETE */
function buildTopBarH(canvasId, min, max, value, interval, redMin, redMax, percSize) {

    //Values
    //var min, max, value, interval, font_size, redMin, redMax;
    //Input: style
    var fill, stroke, stroke_width, tick_width;
    var capFill;
    var pointerFill;
    var cy,cx;

    var paper, gauge, path;
    var font_size;

    try {

        //If max is too low, input interval could be 0: endless loop
        if (interval == 0) interval = 1;

        value = parseFloat(value);

        width = Math.floor(335 * percSize);
        height = Math.floor(75 * percSize);
        stroke_width = 2;
        tick_width = 2;
        fill = "#f1f1f1";
        stroke = "#666666";
        capFill = "#666666";
        pointerFill = "#f15a22";
        font_size = Math.floor(font_size * percSize);

        var canvas = document.getElementById(canvasId);
        if (canvas == null) {
            //alert("Canvas not found: " + canvasId);
            return;
        }

        paper = new Raphael(canvas, width, height);

        //Rettangolo esterno
        gauge = paper.rect(0, 0, width, height, 5);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Tick
        gauge = paper.path(["M", 15, Math.floor(60 * percSize), "H", width - 15]);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Tick: major
        tick = min;
        while (tick <= max) {
            cx = 15 + tick * (width - 30) / max;
            gauge = paper.path(["M", cx, Math.floor(60 * percSize), "V", Math.floor(50 * percSize)]);
            if (tick >= redMin && tick <= redMax && redMin != 0 && redMax != 0) {
                gauge.attr("stroke", "#ff0000");
            } else {
                gauge.attr("stroke", stroke);
            }
            gauge.attr("stroke-width", tick_width);
            tick += interval;
        }
        //Tick: values
        tick = min;
        while (tick <= max) {
            try {
                cx = 15 + tick * (width - 30) / max;
                //gauge = paper.text(cx, Math.floor(69 * percSize), tick);
                gauge = paper.text(cx, Math.floor(69 * percSize), Math.round(tick));
                if (tick >= redMin && tick <= redMax && redMin != 0 && redMax != 0) {
                    gauge.attr("fill", "#ff0000");
                } else {
                    gauge.attr("fill", stroke);
                }
                gauge.attr("font", font_size + "px Arial");
            } catch (ex) { }
            tick += interval;
        }
        //Tick (red)
        if (redMin != null && redMin != 0 && redMax != null && redMax != 0) {
            cx = (redMax - redMin) * (width - 30) / max;
            gauge = paper.path(["M", (width - 15) - cx, Math.floor(60 * percSize), "H", (width - 15)]);
            gauge.attr("fill", "#ff0000");
            gauge.attr("stroke", "#ff0000");
            gauge.attr("stroke-width", 1);
        }
        //Value (bar)
        cx = value * (width - 30) / max;
        gauge = paper.rect(15, 5, cx, Math.floor(40 * percSize), 0);
        gauge.attr("fill", "#f15a22");
        gauge.attr("stroke", "#f15a22");
        gauge.attr("stroke-width", 0);
    } catch (ex) {
        //alert(ex.Message);
    }
}

function buildTopBarH2_0(canvasId, min, max, value, nominalValue, percSize) {

    //Values

    var canvas, paper, gauge, path;
    //Box: width and height
    var box_x0, box_x1, box_y0, box_y1;
    var scale_x0, scale_x100, scale_y0;
    //Text
    var text_x;
    var font_Size;
    //Interval
    var range, intervalValue, intervalX;
    //Values
    var min_x, max_x, nv_x, value_x;
    //UI
    var stroke_width, tick_width;

    try {

        //Init
        box_x0 = 0;
        box_y0 = 0;
        box_x1 = Math.floor(335 * percSize);
        box_y1 = Math.floor(75 * percSize);
        text_x = box_x0 + 10;
        font_size = Math.floor(12 * percSize);
        range = max - min;
        scale_x0 = Math.floor(box_x0 + 15);
        scale_x100 = Math.floor(box_x1 - 15);
        scale_y0 = box_y1 - 20;
        min_x = scale_x0;
        max_x = scale_x100;
        nv_x = (scale_x0 - (nominalValue - min) * (scale_x0 - scale_x100) / range) * percSize;
        value_x = (scale_x0 - (value - min) * (scale_x0 - scale_x100) / range) * percSize;
        intervalValue = nominalValue - min;
        intervalX = nv_x - scale_x0;

        stroke_width = 2;
        tick_width = 2;

        //Init Raphael.js
        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;
        paper = new Raphael(canvas, box_x1, box_y1);

        //Box esterno
        gauge = paper.rect(box_x0, box_y0, box_x1, box_y1, RADIUS_BOX);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Scale
        gauge = paper.path(["M", scale_x0, scale_y0, "H", scale_x100]);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Scale red
        gauge = paper.path(["M", nv_x, scale_y0, "H", max_x]);
        gauge.attr("fill", COLOR_RED);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Value (bar)
        if ((value >= min && value <= max) || (value > max)) {
            var tmpXValue = value_x - scale_x0;
            if (value > max) { tmpXValue = max_x; }
            gauge = paper.rect(scale_x0, box_y0 + 5, tmpXValue, scale_y0 - 10);
            gauge.attr("fill", COLOR_ORANGE);
            gauge.attr("stroke", COLOR_ORANGE);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
        } 

        //Values: min, max, nominal value
        gauge = paper.text(scale_x0, scale_y0 + 10, Math.round(min));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_GRAY);
        gauge = paper.path(["M", scale_x0, scale_y0 + WIDTH_STROKE_1, "V", scale_y0 - 5]);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        gauge = paper.text(nv_x, scale_y0 + 10, Math.round(nominalValue));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_RED);
        gauge = paper.path(["M", nv_x, scale_y0 + WIDTH_STROKE_1, "V", scale_y0 - 5]);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        gauge = paper.text(max_x, scale_y0 + 10, Math.round(max));
        gauge.attr("font", font_size + "px Arial");
        gauge.attr("fill", COLOR_RED);
        gauge = paper.path(["M", max_x, scale_y0 + WIDTH_STROKE_1, "V", scale_y0 - 5]);
        gauge.attr("stroke", COLOR_RED);
        gauge.attr("stroke-width", WIDTH_STROKE_1);

        //Ticks
        for (i = 0; i < 4; i++) {
            gauge = paper.text(min_x + (intervalX / 4) * i, scale_y0 + 10, Math.round(min + (intervalValue / 4) * i));
            gauge.attr("font", font_size + "px Arial");
            gauge.attr("fill", COLOR_GRAY);
            gauge = paper.path(["M", min_x + (intervalX / 4) * i, scale_y0 + WIDTH_STROKE_1, "V", scale_y0 - 5]);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
        }

    } catch (ex) {
        alert(ex.Message);
    }
}

function buildTopHalfCircleGauge(canvasId, min, max, nominalMax, value, interval, absMin, absMax, percSize) {

    //Input: dimensions
    var width, height, radius, cx, cy, cap_radius;
    //Input: style
    //var fill, stroke, stroke_width, tick_width;
    //var capFill;
    //var pointerFill;

    var angle, tick, font_size;
    var paper, gauge, path, pointer_radius;

    try {

        //If max is too low, input interval could be 0: endless loop
        if (interval == 0) interval = 1;

        value = parseFloat(value);

        //All the calculations are done based on "0" (as min)
        var tmpMin, tmpMax, tmpValue, tmpAbsMin, tmpAbsMax, tmpNominalMax, tmpValue;
        tmpMin = 0; //min - min
        tmpMax = max - min;
        tmpAbsMin = absMin - min;
        tmpAbsMax = absMax - min;
        tmpNominalMax = nominalMax - min;
        tmpValue = value - min;

        width = Math.floor(200 * percSize);
        height = Math.floor(200 * percSize);
        radius = Math.floor(178 * percSize);
        cap_radius = Math.floor(15 * percSize);
        pointer_radius = Math.floor(150 * percSize);
        //stroke_width = 2;
        //tick_width = 2;
        //fill = "#f1f1f1";
        //stroke = "#666666";
        //capFill = "#666666";
        //pointerFill = "#f15a22";
        font_size = Math.floor(12 * percSize);

        cx = Math.floor(180 * percSize);
        cy = Math.floor(180 * percSize);

        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;

        paper = new Raphael(canvas, width, height);

        //Quadrante
        gauge = paper.path(["M", cx, cy, "L", Math.floor(cx + radius * Math.cos(c_convertAngle(185))), Math.floor(cy - radius * Math.sin(c_convertAngle(185))), "A", radius, radius, 0, 0, 1, Math.floor(cx + radius * Math.cos(c_convertAngle(85))), Math.floor(cy - radius * Math.sin(c_convertAngle(85))), "L", cx, cy, "Z"]);
        gauge.attr("fill", COLOR_LIGHT_GRAY);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
        gauge.attr("stroke-linejoin", "round");
        //Range interno
        if (tmpNominalMax < tmpMax) {
            //Range: 0 --> nominal max
            angle = Math.PI - (tmpNominalMax * Math.PI / 2) / tmpMax;
            gauge = paper.path(["M", cx - 0.9 * pointer_radius, cy, "A", 0.9 * pointer_radius, 0.9 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.8 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.8 * pointer_radius * Math.sin(angle)), "A", 0.9 * pointer_radius, 0.9 * pointer_radius, 1, 0, 0, cx - 0.9 * pointer_radius, cy]);
            gauge.attr("fill", COLOR_VERY_LIGHT_GRAY);
            gauge.attr("stroke", COLOR_VERY_LIGHT_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
            //Range: nominal max --> max
            gauge = paper.path(["M", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "A", 0.9 * pointer_radius, 0.9 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.9 * pointer_radius * Math.cos(Math.PI / 2)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(Math.PI / 2)), "L", cx, cy - 0.8 * pointer_radius, "A", 0.9 * pointer_radius, 0.9 * pointer_radius, 1, 0, 0, Math.floor(cx + 0.8 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.8 * pointer_radius * Math.sin(angle)), "Z"]);
            gauge.attr("fill", COLOR_GRAY);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_0);
        }
        //Tick: arc
        gauge = paper.path(["M", cx - pointer_radius, cy, "A", pointer_radius, pointer_radius, 0, 0, 1, cx, cy - pointer_radius]);
        gauge.attr("stroke", COLOR_GRAY);
        gauge.attr("stroke-width", WIDTH_STROKE_2);
        //Tick: values (major)
        tick = tmpMin;
        while (tick <= tmpMax) {
            angle = Math.PI - (tick * Math.PI / 2) / tmpMax;
            gauge = paper.path(["M", Math.floor(cx + 0.95 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.95 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))]);
            //gauge.attr("fill",fill);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_2);
            tick += interval;
        }
        //Tick: values (min)
        tick = interval / 2;
        while (tick <= tmpMax) {
            angle = Math.PI - (tick * Math.PI / 2) / tmpMax;
            gauge = paper.path(["M", Math.floor(cx + 0.97 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.97 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))]);
            //gauge.attr("fill",fill);
            gauge.attr("stroke", COLOR_GRAY);
            gauge.attr("stroke-width", WIDTH_STROKE_2);
            tick += interval;
        }
        //Tick: values
        tick = tmpMin;
        while (tick <= tmpMax) {
            angle = Math.PI - (tick * Math.PI / 2) / tmpMax;
            //gauge = paper.text(Math.floor(cx + 1.07 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.07 * pointer_radius * Math.sin(angle)), Math.round((tick + min) * 100) / 100);
            gauge = paper.text(Math.floor(cx + 1.112 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.112 * pointer_radius * Math.sin(angle)), Math.round(tick + min));
            gauge.attr("fill", COLOR_GRAY);
            gauge.attr("font", font_size + "px Arial");
            //gauge.attr("font-weight","bold");
            tick += interval;
        }
        //Pointer (abs min)
        /*if (tmpAbsMin > tmpMin) {
            angle = Math.PI - (tmpAbsMin * Math.PI / 2) / tmpMax;
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))]);
            gauge.attr("fill", COLOR_RED);
            gauge.attr("stroke", COLOR_RED);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
            gauge.attr("opacity", OPACITY_0_5);
        }*/
        //Pointer (abs max)
        /*if (tmpAbsMax > tmpMax) {
            angle = Math.PI - (tmpAbsMax * Math.PI / 2) / tmpMax;
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))]);
            gauge.attr("fill", COLOR_BLUE);
            gauge.attr("stroke", COLOR_BLUE);
            gauge.attr("stroke-width", WIDTH_STROKE_1);
            gauge.attr("opacity", OPACITY_0_5);
        }*/
        //Pointer
        if (tmpValue < tmpMin) {
            angle = 3.2;
        } else if (tmpValue > tmpMax)  {
            //Value bigger than Max
            angle = 1.52;
        } else if (tmpValue <= tmpMax) {
            angle = Math.PI - (tmpValue * Math.PI / 2) / tmpMax;
        } 
        gauge = paper.path(["M", cx + Math.floor(5 * Math.cos(angle + Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle + Math.PI / 2)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "L", cx + Math.floor(5 * Math.cos(angle - Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle - Math.PI / 2)), "Z"]);
        gauge.attr("fill", COLOR_ORANGE);
        gauge.attr("stroke", COLOR_ORANGE);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
        //Cap
        gauge = paper.circle(cx, cy, cap_radius);
        gauge.attr("fill", "r(0.25, 0.75)#ffffff-#000000");
        gauge.attr("stroke", COLOR_BLACK);
        gauge.attr("stroke-width", WIDTH_STROKE_1);
    } catch (ex) {
        alert(ex.message);
    }
}

function buildTopLine(canvasId, cx, cy, width, height, color, strokeWidth) {

    try {

        var canvas = document.getElementById(canvasId);
        if (canvas == null) {
            //alert("Canvas not found: " + canvasId);
            return;
        }

        /*var cx = Math.abs(x2);
        var cy = Math.abs(y2);
        var paper = new Raphael(canvas, cx * 2, cy * 2);

        var line = paper.path(["M", cx, cy, "L", cx + x2, cy + y2]);
        line.attr("fill", color);
        line.attr("stroke", color);
        line.attr("stroke-width", strokeWidth);*/

        /*var paper = new Raphael(canvas, width, 2*cy);
        var line = paper.path(["M", cx, cy, "L", cx + width, cy + height]);
        line.attr("fill", color);
        line.attr("stroke", color);
        line.attr("stroke-width", strokeWidth);
        */

        var paper = new Raphael(canvas, (width==0?1:width), Math.abs((height==0?1:height)));
        var line = paper.path(["M", cx, cy, "L", cx + width, cy + height]);
        line.attr("fill", color);
        line.attr("stroke", color);
        line.attr("stroke-width", strokeWidth);

    } catch (ex) {
    //alert(ex.Message);
    }

}

function buildTopGaugeZero(canvasId, max, value, interval, percSize) {

    //NO: min, nominalMax, interval, absMin, absMax

    //Input: dimensions
    var width, height, radius, cx, cy, cap_radius;
    //Input: style
    var fill, stroke, stroke_width, tick_width;
    var capFill;
    var pointerFill;

    var angle, angle2, tick, font_size;
    var paper, gauge, path, pointer_radius;
    var min;

    try {

        //If max is too low, input interval could be 0: endless loop
        if (interval == 0) interval = 1;

        value = parseFloat(value);

        //All the calculations are done based on "0" (as min)
        var tmpMin, tmpMax, tmpValue, tmpValue; /*, tmpAbsMin, tmpAbsMax, tmpNominalMax,*/;
        //interval = interval * 2;
        //max = 2 * max;
        min = -max;
        tmpMin = 0; //min - min
        tmpMax = max - min;
        //tmpAbsMin = absMin - min;
        //tmpAbsMax = absMax - min;
        //tmpNominalMax = nominalMax - min;
        tmpValue = value - min;

        width = Math.floor(200 * percSize);
        height = Math.floor(200 * percSize);
        radius = Math.floor(100 * percSize);
        cap_radius = Math.floor(10 * percSize);
        pointer_radius = Math.floor(75 * percSize);
        stroke_width = 2;
        tick_width = 2;
        fill = "#f1f1f1";
        stroke = "#666666";
        capFill = "#666666";
        pointerFill = "#f15a22";
        font_size = Math.floor(font_size * percSize);

        cx = width / 2;
        cy = height / 2;

        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;

        paper = new Raphael(canvas, width, height);

        //Quadrante
        gauge = paper.circle(cx, cy, radius);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Range interno
        /*if (tmpNominalMax < tmpMax) {
            //Range: 0 --> nominal max
            deltaX = Math.floor(0.85 * pointer_radius * Math.sin(c_convertAngle(30)));
            deltaY = Math.floor(0.85 * pointer_radius * Math.cos(c_convertAngle(30)));
            angle = -1 * (c_convertAngle(120) + (tmpNominalMax * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 1, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle)), "A", 0.75 * pointer_radius, 0.75 * pointer_radius, 1, 1, 0, cx - deltaX, cy + deltaY]);
            gauge.attr("fill", "#c0c0c0");
            gauge.attr("stroke", "#c0c0c0");
            gauge.attr("stroke-width", 0);
            //Range: nominal max -->  max
            angle2 = -1 * (c_convertAngle(120) + (tmpMax * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle2)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle2)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 1, 0, 0, Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle))]);
            gauge.attr("fill", stroke);
            gauge.attr("stroke", stroke);
            gauge.attr("stroke-width", 0);
        }*/
        //Tick: arc
        deltaX = Math.floor(pointer_radius * Math.sin(c_convertAngle(30)));
        deltaY = Math.floor(pointer_radius * Math.cos(c_convertAngle(30)));
        gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", pointer_radius, pointer_radius, 0, 1, 1, cx + deltaX, cy + deltaY]);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", tick_width);
        //Tick: values (major)
        tick = tmpMin;
        while (tick <= tmpMax+0.1) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle))]);
            //gauge.attr("fill",fill);
            gauge.attr("stroke", stroke);
            gauge.attr("stroke-width", tick_width);
            tick += interval;
        }
        //Tick: values (minor)
        tick = interval / 2;
        while (tick <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.95 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.95 * pointer_radius * Math.sin(angle))]);
            gauge.attr("stroke", stroke);
            gauge.attr("stroke-width", tick_width);
            tick += interval;
        }
        //Tick: "0" central value
        try {
            angle = Math.PI / 2; ;
            gauge = paper.text(Math.floor(cx + 1.18 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.18 * pointer_radius * Math.sin(angle)), "0");
            gauge.attr("fill", stroke);
            gauge.attr("font", font_size + "px Arial");
        } catch (ex) { }
        //Tick: values (all the calcutions are "0" based but actual values must be written
        tick = tmpMin;
        while (tick <= tmpMax+0.1) {
            try {
                angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
                //gauge = paper.text(Math.floor(cx + 1.13 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.13 * pointer_radius * Math.sin(angle)), Math.round((tick + min) * 100) / 100);
                gauge = paper.text(Math.floor(cx + 1.18 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.18 * pointer_radius * Math.sin(angle)), Math.round(tick + min));
                gauge.attr("fill", stroke);
                gauge.attr("font", font_size + "px Arial");
            } catch (ex) { }
            tick += interval;
        }
        //Pointer (abs min)
        /*if (tmpAbsMin > tmpMin) {
            angle = -1 * (c_convertAngle(120) + (tmpAbsMin * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "Z"]);
            gauge.attr("fill", "red");
            gauge.attr("stroke", "red");
            gauge.attr("stroke-width", 1);
            gauge.attr("opacity", 0.5);
        }
        //Pointer (abs max)
        if (tmpAbsMax > tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tmpAbsMax * c_convertAngle(300)) / tmpMax);
            gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))], "Z");
            gauge.attr("fill", "blue");
            gauge.attr("stroke", "blue");
            gauge.attr("stroke-width", 1);
            gauge.attr("opacity", 0.5);
        }*/
        //Pointer
        if (tmpValue <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tmpValue * c_convertAngle(300)) / tmpMax);
        } else {
            angle = -1.2;
        }
        gauge = paper.path(["M", cx + Math.floor(5 * Math.cos(angle + Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle + Math.PI / 2)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "L", cx + Math.floor(5 * Math.cos(angle - Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle - Math.PI / 2)), "Z"]);
        gauge.attr("fill", pointerFill);
        gauge.attr("stroke", pointerFill);
        gauge.attr("stroke-width", 1);
        //Cap
        gauge = paper.circle(cx, cy, cap_radius);
        gauge.attr("fill", "r(0.25, 0.75)#ffffff-#000000");
        gauge.attr("stroke", "#000000");
        gauge.attr("stroke-width", 1);
    } catch (ex) {
        //alert(ex.message);
    }
}

function buildTopGaugeIndCap(canvasId, value, nSteps, isInd, percSize) {

    //NO: min, nominalMax, interval, absMin, absMax, max, interval;

    /*alert("*** Step 1 - Input values ***" + "\n" +
          "canvasId: " + canvasId + "\n" +
          "value: " + value.toString() + "\n" +
          "nSteps: " + nSteps.toString() + "\n" +
          "isInd: " + isInd.toString() + "\n" +
          "percSize: " + percSize.toString());*/

    //Input: dimensions
    var width, height, radius, cx, cy, cap_radius;
    //Input: style
    var fill, stroke, stroke_width, tick_width;
    var capFill;
    var pointerFill;

    var angle, angle2, tick, font_size;
    var paper, gauge, path, pointer_radius;
    var label;
    var min, max, interval;

    try {
        value = parseFloat(value);

        //All the calculations are done based on "0" (as min)
        var tmpMin, tmpMax, tmpValue, tmpValue; /*, tmpAbsMin, tmpAbsMax, tmpNominalMax,*/;
        max = 2;
        min = 0;
        interval = max / nSteps;
        tmpMin = 0; //min - min
        tmpMax = max - min;
        //tmpAbsMin = absMin - min;
        //tmpAbsMax = absMax - min;
        //tmpNominalMax = nominalMax - min;
        tmpValue = value - min;

        /*alert("*** Step 2 - Calculated values ***" + "\n" +
          "max: " + max.toString() + "\n" +
          "min: " + min.toString() + "\n" +
          "interval: " + interval.toString() + "\n" +
          "tmpMin: " + tmpMin.toString() + "\n" +
          "tmpMax: " + tmpMax.toString() + "\n" +
          "tmpValue: " + tmpValue.toString());*/

        width = Math.floor(200 * percSize);
        height = Math.floor(200 * percSize)
        radius = Math.floor(100 * percSize);
        cap_radius = Math.floor(10 * percSize);
        pointer_radius = Math.floor(75 * percSize);
        stroke_width = 2;
        tick_width = 2;
        fill = "#f1f1f1";
        stroke = "#666666";
        capFill = "#666666";
        pointerFill = "#f15a22";
        font_size = Math.floor(font_size * percSize);
        cx = width / 2;
        cy = height / 2;

        var canvas = document.getElementById(canvasId);
        if (canvas == null) return;

        paper = new Raphael(canvas, width, height);
        //Quadrante
        gauge = paper.circle(cx, cy, radius);
        gauge.attr("fill", fill);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 1);
        //Range interno
        /*if (tmpNominalMax < tmpMax) {
        //Range: 0 --> nominal max
        deltaX = Math.floor(0.85 * pointer_radius * Math.sin(c_convertAngle(30)));
        deltaY = Math.floor(0.85 * pointer_radius * Math.cos(c_convertAngle(30)));
        angle = -1 * (c_convertAngle(120) + (tmpNominalMax * c_convertAngle(300)) / tmpMax);
        gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 1, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle)), "A", 0.75 * pointer_radius, 0.75 * pointer_radius, 1, 1, 0, cx - deltaX, cy + deltaY]);
        gauge.attr("fill", "#c0c0c0");
        gauge.attr("stroke", "#c0c0c0");
        gauge.attr("stroke-width", 0);
        //Range: nominal max -->  max
        angle2 = -1 * (c_convertAngle(120) + (tmpMax * c_convertAngle(300)) / tmpMax);
        gauge = paper.path(["M", Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 0, 0, 1, Math.floor(cx + 0.85 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.85 * pointer_radius * Math.sin(angle2)), "L", Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle2)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle2)), "A", 0.85 * pointer_radius, 0.85 * pointer_radius, 1, 0, 0, Math.floor(cx + 0.70 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.70 * pointer_radius * Math.sin(angle))]);
        gauge.attr("fill", stroke);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", 0);
        }*/
        //Tick: arc
        deltaX = Math.floor(pointer_radius * Math.sin(c_convertAngle(30)));
        deltaY = Math.floor(pointer_radius * Math.cos(c_convertAngle(30)));
        gauge = paper.path(["M", cx - deltaX, cy + deltaY, "A", pointer_radius, pointer_radius, 0, 1, 1, cx + deltaX, cy + deltaY]);
        gauge.attr("stroke", stroke);
        gauge.attr("stroke-width", tick_width);
        //Tick: values (major)
        tick = tmpMin;
        while (tick <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            /*alert("*** Step 3 - Major ticks ***" + "\n" +
                  "tick: " + tick.toString() + "\n" +
                  "angle: " + angle.toString());*/
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle))]);
            //gauge.attr("fill",fill);
            gauge.attr("stroke", stroke);
            gauge.attr("stroke-width", tick_width);
            tick += interval;
            
        }
        //Tick: values (minor)
        tick = interval / 2;
        while (tick <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
            /*alert("*** Step 4 - Minor ticks ***" + "\n" +
                  "tick: " + tick.toString() + "\n" +
                  "angle: " + angle.toString());*/
            gauge = paper.path(["M", Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "L", Math.floor(cx + 0.95 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.95 * pointer_radius * Math.sin(angle))]);
            gauge.attr("stroke", stroke);
            gauge.attr("stroke-width", tick_width);
            tick += interval;
        }
        //Tick: "1,00" central value
        try {
            angle = Math.PI / 2;
            /*alert("*** Step 5 - Central values ***" + "\n" +
                  "angle: " + angle.toString());*/
            gauge = paper.text(Math.floor(cx + 1.18 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.18 * pointer_radius * Math.sin(angle)), "1.00");
            gauge.attr("fill", stroke);
            gauge.attr("font", font_size + "px Arial");
        } catch (ex) { alert(ex); }
        //Tick: values (all the calcutions are "0" based but actual values must be written
        tick = tmpMin;
        while (tick <= tmpMax) {
            try {
                angle = -1 * (c_convertAngle(120) + (tick * c_convertAngle(300)) / tmpMax);
                label = parseFloat(tick + min);
                if (label > 1) {
                    label = Math.round((2 - label) * 10) / 10;
                }
                /*alert("*** Step 6 - Values ticks ***" + "\n" +
                 "tick: " + tick.toString() + "\n" +
                 "angle: " + angle.toString() + "\n" +
                 "label: " + label);*/
                gauge = paper.text(Math.floor(cx + 1.13 * pointer_radius * Math.cos(angle)), Math.floor(cy - 1.13 * pointer_radius * Math.sin(angle)), label.toString());
                gauge.attr("fill", stroke);
                gauge.attr("font", font_size + "px Arial");
            } catch (ex) { alert(ex) }
            tick += interval;
        }
        //Pointer (abs min)
        /*if (tmpAbsMin > tmpMin) {
        angle = -1 * (c_convertAngle(120) + (tmpAbsMin * c_convertAngle(300)) / tmpMax);
        gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle)), "Z"]);
        gauge.attr("fill", "red");
        gauge.attr("stroke", "red");
        gauge.attr("stroke-width", 1);
        gauge.attr("opacity", 0.5);
        }
        //Pointer (abs max)
        if (tmpAbsMax > tmpMax) {
        angle = -1 * (c_convertAngle(120) + (tmpAbsMax * c_convertAngle(300)) / tmpMax);
        gauge = paper.path(["M", cx, cy, "L", cx, cy, Math.floor(cx + pointer_radius * Math.cos(angle)), Math.floor(cy - pointer_radius * Math.sin(angle))], "Z");
        gauge.attr("fill", "blue");
        gauge.attr("stroke", "blue");
        gauge.attr("stroke-width", 1);
        gauge.attr("opacity", 0.5);
        }*/
        //Pointer
        //alert("*** Step 7 - Pointer ***");
        tmpValue = Math.abs(tmpValue);
        if (isInd==0) {
            tmpValue = tmpMax - tmpValue;
        }
        if (tmpValue <= tmpMax) {
            angle = -1 * (c_convertAngle(120) + (tmpValue * c_convertAngle(300)) / tmpMax);
        } else {
            angle = -1.2;
        }
        gauge = paper.path(["M", cx + Math.floor(5 * Math.cos(angle + Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle + Math.PI / 2)), "L", Math.floor(cx + 0.9 * pointer_radius * Math.cos(angle)), Math.floor(cy - 0.9 * pointer_radius * Math.sin(angle)), "L", cx + Math.floor(5 * Math.cos(angle - Math.PI / 2)), cy - Math.floor(5 * Math.sin(angle - Math.PI / 2)), "Z"]);
        gauge.attr("fill", pointerFill);
        gauge.attr("stroke", pointerFill);
        gauge.attr("stroke-width", 1);
        //Cap
        //alert("*** Step 8 - Central cap ***");
        gauge = paper.circle(cx, cy, cap_radius);
        gauge.attr("fill", "r(0.25, 0.75)#ffffff-#000000");
        gauge.attr("stroke", "#000000");
        gauge.attr("stroke-width", 1);
        //CAP/IND
        //alert("*** Step 9 - Cap/Ind ***");
        gauge = paper.text(Math.floor(cx + pointer_radius - 40), Math.floor(cy), "CAP");
        gauge = paper.text(Math.floor(cx - pointer_radius + 40), Math.floor(cy), "IND");
    } catch (ex) {
        alert(ex.message);
    }
}